@@ -9,7 +9,7 @@ from bentoctl.exceptions import BentoctlException
 from bentoctl.utils import set_debug_mode
 from bentoctl.utils.usage_stats import (
     BENTOML_DO_NOT_TRACK,
-    CliEvent,
+    BentoctlCliEvent,
     cli_events_map,
     track,
 )
@@ -76,19 +76,19 @@ class BentoctlCommandGroup(click.Group):
                 )
             elif cmd_group.name == "operator":
 
-                def get_tracking_event(return_value):  # pylint: disable=unused-argument
-                    return CliEvent(
+                def get_tracking_event(_):  # pylint: disable=unused-argument
+                    return BentoctlCliEvent(
                         cmd_group.name, command_name, operator=kwargs.get("name", None)
                     )
 
             else:
 
-                def get_tracking_event(ret):  # pylint: disable=unused-argument
-                    return CliEvent(cmd_group.name, command_name)
+                def get_tracking_event(_):  # pylint: disable=unused-argument
+                    return BentoctlCliEvent(cmd_group.name, command_name)
 
             try:
                 return_value = func(*args, **kwargs)
-                event = get_tracking_event(return_value=return_value)
+                event = get_tracking_event(return_value)
                 duration_in_ms = time.time_ns() - start_time
                 event.duration_in_ms = duration_in_ms / 1e6
                 track(event)
